@@ -70,6 +70,12 @@ def delete_password(service_name, username):
     _keyring_backend.delete_password(service_name, username)
 
 
+def get_credential(service_name, username):
+    """Get a Credential for the specified service.
+    """
+    return _keyring_backend.get_credential(service_name, username)
+
+
 def recommended(backend):
     return backend.priority >= 1
 
@@ -86,7 +92,7 @@ def init_backend(limit=None):
     set_keyring(
         load_env()
         or load_config()
-        or max(keyrings, default=fail.Keyring, key=by_priority)
+        or max(keyrings, default=fail.Keyring(), key=by_priority)
     )
 
 
